##  Capture Risk Remediation Decisions
The application owner collaborates with leadership and risk partners to determine whether to accept or address identified risks. Risks are categorized as accepted when the risk to the application is considered tolerable, despite its persistence. Risk acceptance decisions are influenced by various factors, including business criticality of application, absence of alternative IT components, budget constraints, operational limitations, or even a lack of time to schedule an outage to address the risk. When the risk to the application has been effectively mitigated or remediated, the risks are categorized as addressed.
Ensure that the decision on Obsolescence Risk Status is maintained on the relation between the IT component and application fact sheets. Leverage surveys to determine from application and business owners whether the obsolescence risk status is accepted or requires addressing. When no data is recorded for this attribute, it will be interpreted and rolled up to the application as either Unaddressed Phase Out or Unaddressed Risk in the obsolescence risk views of reports.
![Obsolescence Risk Status Field](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f8d1b7a441014b070b919bda19efb_LowRes.png)
Obsolescence Risk Status Field
